@@ -22,7 +22,7 @@
 package proxy
 
 import (
-	"gir/glib-2.0"
+	"pkg.deepin.io/gir/glib-2.0"
 	C "gopkg.in/check.v1"
 	"pkg.deepin.io/lib/log"
 	"testing"
